@@ -91,7 +91,8 @@ def _get_handler(res):
             [
                 (plugin.get_resource_indexer_weight(res), plugin)
                 for plugin in p.PluginImplementations(IResourceIndexer)
-            ]
+            ],
+            key=lambda pair: pair[0]
         )
         if plugin and weight > 0
     ]
